@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ public:
     Brand brand;
 };
 
-KITINERARY_MAKE_SIMPLE_CLASS(RentalCar)
+KITINERARY_MAKE_CLASS(RentalCar)
 KITINERARY_MAKE_PROPERTY(RentalCar, QString, name, setName)
 KITINERARY_MAKE_PROPERTY(RentalCar, QString, model, setModel)
 KITINERARY_MAKE_PROPERTY(RentalCar, Organization, rentalCompany, setRentalCompany)
