@@ -104,7 +104,7 @@ static bool conflictIfSet(const QDateTime &lhs, const QDateTime &rhs)
     return lhs.isValid() && rhs.isValid() && lhs != rhs;
 }
 
-static void applyFlightTimes(QVector<QVariant> &result, const QDateTime &boarding, const QDateTime &dep, const QDateTime &arr)
+static void applyFlightTimes(QList<QVariant> &result, const QDateTime &boarding, const QDateTime &dep, const QDateTime &arr)
 {
     for (auto &res : result) {
         auto flightRes = res.value<FlightReservation>();
@@ -134,7 +134,7 @@ ExtractorResult GenericBoardingPassExtractor::extract(const ExtractorDocumentNod
 {
     static TerminalFinder terminalFinder(u"^", u"(?=\\b|\\s|$)");
 
-    QVector<QVariant> fullResult;
+    QList<QVariant> fullResult;
 
     const auto pdf = node.content<PdfDocument*>();
 
@@ -148,7 +148,7 @@ ExtractorResult GenericBoardingPassExtractor::extract(const ExtractorDocumentNod
     for (auto it = bcbpNodes.begin(); it != bcbpNodes.end(); ++it) {
         QDate departureDay;
         KnowledgeDb::IataCode from, to;
-        QVector<QVariant> result;
+        QList<QVariant> result;
 
         // 1 determine which airports we need to look for on the same page
         const auto pageNum = (*it).location().toInt();
