@@ -23,7 +23,8 @@ const tariffs = {
 
 function parseSncfPdfText(text) {
     var reservations = new Array();
-    var bookingRef = text.match(/(?:DOSSIER VOYAGE|BOOKING FILE REFERENCE|REFERENCE NUMBER|REISEREFERENZ) ?: +([A-Z0-9]{6})/);
+    const bookingRef = text.match(/(?:DOSSIER VOYAGE|BOOKING FILE REFERENCE|REFERENCE NUMBER|REISEREFERENZ) ?: +([A-Z0-9]{6})/);
+    const price = text.match(/(\d+,\d\d EUR)/);
 
     var pos = 0;
     while (true) {
@@ -62,6 +63,9 @@ function parseSncfPdfText(text) {
             res.reservedTicket.ticketedSeat.seatNumber = seatRes[2];
         }
 
+        if (price)
+            ExtractorEngine.extractPrice(price[1], res);
+
         reservations.push(res);
         if (index == 0)
             break;
@@ -74,6 +78,7 @@ function parseSncfPdfText(text) {
 function parseInouiPdfText(page)
 {
     var reservations = new Array();
+    const price = page.text.match(/(\d+,\d\d EUR)/);
     var text = page.textInRect(0.0, 0.0, 0.5, 1.0);
 
     var date = text.match(/(\d+\.? [^ ]+ \d{4})\n/)
@@ -106,6 +111,9 @@ function parseInouiPdfText(page)
             res.reservedTicket.ticketedSeat.seatNumber = seat[2];
         }
 
+        if (price)
+            ExtractorEngine.extractPrice(price[1], res);
+
         reservations.push(res);
         if (endPos == 0)
             break;
@@ -267,6 +275,8 @@ function parseSecutix(barcode)
     res.underName.familyName = code.substr(116, 19);
     res.underName.givenName = code.substr(135, 19);
     res.programMembershipUsed.programName = tariffs[code.substr(92, 4)];
+    res.reservedTicket.totalPrice = code.substr(226, 10) / 100;
+    res.reservedTicket.priceCurrency = 'EUR';
     return res;
 }
 
@@ -335,6 +345,10 @@ function parseOuiSummary(html)
         res.reservationFor.trainNumber = trainNum[0].content + " " + trainNum[1].content;
     }
 
+    const price = html.eval('//*[@class="transaction__total-amount-value"]');
+    if (price)
+        ExtractorEngine.extractPrice(price[0].recursiveContent, res);
+
     // check if this is a return ticket
     var retourTime = html.eval('//*[@data-select="travel-returnDate"]');
     if (retourTime.length == 0) {
@@ -348,6 +362,8 @@ function parseOuiSummary(html)
     if (trainNum.length == 2 || trainNum[1].content == trainNum[3].content) {
         retour.reservationFor.trainNumber = trainNum[0].content + " " + trainNum[1].content;
     }
+    if (price)
+        ExtractorEngine.extractPrice(price[0].recursiveContent, retour);
 
     return [res, retour];
 }
@@ -440,6 +456,12 @@ function parseOuigoTicket(pdf, node) {
             break;
         }
     }
+
+    const price = text.match(/ (\d+\.\d\d)€/);
+    if (price) {
+        res.totalPrice = price[1];
+        res.priceCurrency = 'EUR';
+    }
     return res;
 }
 
