@@ -21,6 +21,7 @@
 #include <QDebug>
 #include <QJsonDocument>
 #include <QJsonObject>
+#include <QTimeZone>
 
 #include <zlib.h>
 
@@ -301,7 +302,7 @@ QDateTime Uic9183Parser::validFrom() const
             if (dt.date().year() < 2000) {
                 dt = dt.addYears(100);
             }
-            dt.setTimeSpec(Qt::UTC);
+            dt.setTimeZone(QTimeZone::utc());
             return dt;
         }
     }
@@ -359,7 +360,7 @@ QDateTime Uic9183Parser::validUntil() const
             if (dt.date().year() < 2000) {
                 dt = dt.addYears(100);
             }
-            dt.setTimeSpec(Qt::UTC);
+            dt.setTimeZone(QTimeZone::utc());
             return dt;
         }
     }
@@ -446,6 +447,19 @@ Person Uic9183Parser::person() const
     return {};
 }
 
+static void fixFcbStationCode(TrainStation &station)
+{
+    // UIC codes in Germany are wildly unreliable, there seem to be different
+    // code tables in use by different operators, so we unfortunately have to ignore
+    // those entirely
+    if (station.identifier().startsWith(QLatin1String("uic:80"))) {
+        PostalAddress addr;
+        addr.setAddressCountry(QStringLiteral("DE"));
+        station.setAddress(addr);
+        station.setIdentifier(QString());
+    }
+}
+
 TrainStation Uic9183Parser::outboundDepartureStation() const
 {
     TrainStation station;
@@ -480,6 +494,7 @@ TrainStation Uic9183Parser::outboundDepartureStation() const
             station.setName(nrt.fromStationNameUTF8);
             station.setIdentifier(FcbUtil::fromStationIdentifier(nrt));
         }
+        fixFcbStationCode(station);
     }
 
     return station;
@@ -518,6 +533,7 @@ TrainStation Uic9183Parser::outboundArrivalStation() const
             station.setName(nrt.toStationNameUTF8);
             station.setIdentifier(FcbUtil::toStationIdentifier(nrt));
         }
+        fixFcbStationCode(station);
     }
 
     return station;
@@ -557,6 +573,7 @@ TrainStation Uic9183Parser::returnDepartureStation() const
                 }
             }
         }
+        fixFcbStationCode(station);
     }
 
     return station;
@@ -596,6 +613,7 @@ TrainStation Uic9183Parser::returnArrivalStation() const
                 }
             }
         }
+        fixFcbStationCode(station);
     }
 
     return station;
